==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/dyo.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "dyo",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ten",
    "Tal",
    "Ala",
    "Ara",
    "Arj",
    "Sib",
    "Dim",
  ],
  day_format_narrow => [
    "T",
    "T",
    "A",
    "A",
    "A",
    "S",
    "D",
  ],
  day_format_wide => [
    "Tene\N{U+014b}",
    "Talata",
    "Alarbay",
    "Aramisay",
    "Arjuma",
    "Sibiti",
    "Dimas",
  ],
  day_stand_alone_abbreviated => [
    "Ten",
    "Tal",
    "Ala",
    "Ara",
    "Arj",
    "Sib",
    "Dim",
  ],
  day_stand_alone_narrow => [
    "T",
    "T",
    "A",
    "A",
    "A",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "Tene\N{U+014b}",
    "Talata",
    "Alarbay",
    "Aramisay",
    "Arjuma",
    "Sibiti",
    "Dimas",
  ],
  era_abbreviated => [
    "ArY",
    "AtY",
  ],
  era_narrow => [
    "ArY",
    "AtY",
  ],
  era_wide => [
    "Ari\N{U+014b}uu Yeesu",
    "Atoo\N{U+014b}e Yeesu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Jola-Fonyi",
  month_format_abbreviated => [
    "Sa",
    "Fe",
    "Ma",
    "Ab",
    "Me",
    "Su",
    "S\N{U+00fa}",
    "Ut",
    "Se",
    "Ok",
    "No",
    "De",
  ],
  month_format_narrow => [
    "S",
    "F",
    "M",
    "A",
    "M",
    "S",
    "S",
    "U",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Sanvie",
    "F\N{U+00e9}birie",
    "Mars",
    "Aburil",
    "Mee",
    "Sue\N{U+014b}",
    "S\N{U+00fa}uyee",
    "Ut",
    "Settembar",
    "Oktobar",
    "Novembar",
    "Disambar",
  ],
  month_stand_alone_abbreviated => [
    "Sa",
    "Fe",
    "Ma",
    "Ab",
    "Me",
    "Su",
    "S\N{U+00fa}",
    "Ut",
    "Se",
    "Ok",
    "No",
    "De",
  ],
  month_stand_alone_narrow => [
    "S",
    "F",
    "M",
    "A",
    "M",
    "S",
    "S",
    "U",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Sanvie",
    "F\N{U+00e9}birie",
    "Mars",
    "Aburil",
    "Mee",
    "Sue\N{U+014b}",
    "S\N{U+00fa}uyee",
    "Ut",
    "Settembar",
    "Oktobar",
    "Novembar",
    "Disambar",
  ],
  name => "Jola-Fonyi",
  native_language => "joola",
  native_name => "joola",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/dyo.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "dyo",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ten",
    "Tal",
    "Ala",
    "Ara",
    "Arj",
    "Sib",
    "Dim",
  ],
  day_format_narrow => [
    "T",
    "T",
    "A",
    "A",
    "A",
    "S",
    "D",
  ],
  day_format_wide => [
    "Tene\N{U+014b}",
    "Talata",
    "Alarbay",
    "Aramisay",
    "Arjuma",
    "Sibiti",
    "Dimas",
  ],
  day_stand_alone_abbreviated => [
    "Ten",
    "Tal",
    "Ala",
    "Ara",
    "Arj",
    "Sib",
    "Dim",
  ],
  day_stand_alone_narrow => [
    "T",
    "T",
    "A",
    "A",
    "A",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "Tene\N{U+014b}",
    "Talata",
    "Alarbay",
    "Aramisay",
    "Arjuma",
    "Sibiti",
    "Dimas",
  ],
  era_abbreviated => [
    "ArY",
    "AtY",
  ],
  era_narrow => [
    "ArY",
    "AtY",
  ],
  era_wide => [
    "Ari\N{U+014b}uu Yeesu",
    "Atoo\N{U+014b}e Yeesu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Jola-Fonyi",
  month_format_abbreviated => [
    "Sa",
    "Fe",
    "Ma",
    "Ab",
    "Me",
    "Su",
    "S\N{U+00fa}",
    "Ut",
    "Se",
    "Ok",
    "No",
    "De",
  ],
  month_format_narrow => [
    "S",
    "F",
    "M",
    "A",
    "M",
    "S",
    "S",
    "U",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Sanvie",
    "F\N{U+00e9}birie",
    "Mars",
    "Aburil",
    "Mee",
    "Sue\N{U+014b}",
    "S\N{U+00fa}uyee",
    "Ut",
    "Settembar",
    "Oktobar",
    "Novembar",
    "Disambar",
  ],
  month_stand_alone_abbreviated => [
    "Sa",
    "Fe",
    "Ma",
    "Ab",
    "Me",
    "Su",
    "S\N{U+00fa}",
    "Ut",
    "Se",
    "Ok",
    "No",
    "De",
  ],
  month_stand_alone_narrow => [
    "S",
    "F",
    "M",
    "A",
    "M",
    "S",
    "S",
    "U",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Sanvie",
    "F\N{U+00e9}birie",
    "Mars",
    "Aburil",
    "Mee",
    "Sue\N{U+014b}",
    "S\N{U+00fa}uyee",
    "Ut",
    "Settembar",
    "Oktobar",
    "Novembar",
    "Disambar",
  ],
  name => "Jola-Fonyi",
  native_language => "joola",
  native_name => "joola",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
